from setuptools import setup

setup(name='Sree-probability',
      version='0.2',
      description='Gaussian distributions',
      packages=['Sree-probability'],
      author='Sreedhar Gunda',
      author_email='blueskybuildtech@gmail.com',
      zip_safe=False)
